@@ -27,6 +27,7 @@ from typing import Tuple
 import aiohttp
 import humanfriendly
 import requests
+from requests import HTTPError
 from requests.adapters import HTTPAdapter
 
 from .config import AlluxioClientConfig
@@ -41,7 +42,8 @@ from .const import FULL_CHUNK_URL_FORMAT
 from .const import FULL_PAGE_URL_FORMAT
 from .const import FULL_RANGE_URL_FORMAT
 from .const import GET_FILE_STATUS_URL_FORMAT
-from .const import GET_NODE_ADDRESS
+from .const import GET_NODE_ADDRESS_DOMAIN
+from .const import GET_NODE_ADDRESS_IP
 from .const import HEAD_URL_FORMAT
 from .const import LIST_URL_FORMAT
 from .const import LOAD_PROGRESS_URL_FORMAT
@@ -55,6 +57,7 @@ from .const import TAIL_URL_FORMAT
 from .const import TOUCH_URL_FORMAT
 from .const import WRITE_CHUNK_URL_FORMAT
 from .const import WRITE_PAGE_URL_FORMAT
+from .loadbalance import WorkerListLoadBalancer
 from .utils import set_log_level
 from .worker_ring import ConsistentHashProvider
 
@@ -114,8 +117,6 @@ class AlluxioClient:
 
     Examples
     --------
-    >>> # Launch Alluxio with ETCD as service discovery
-    >>> alluxio = AlluxioClient(etcd_hosts="localhost")
     >>> # Or launch Alluxio with user provided worker list
     >>> alluxio = AlluxioClient(worker_hosts="host1,host2,host3")
 
@@ -145,31 +146,30 @@ class AlluxioClient:
         Inits Alluxio file system.
 
         Args:
-            etcd_hosts (str, optional):
-                The hostnames of ETCD to get worker addresses from
-                The hostnames in host1,host2,host3 format. Either etcd_hosts or worker_hosts should be provided, not both.
             worker_hosts (str, optional):
-                The worker hostnames in host1,host2,host3 format. Either etcd_hosts or worker_hosts should be provided, not both.
+                The worker hostnames in host1,host2,host3 format. Either load_balance_domain or worker_hosts should be provided, not both.
             options (dict, optional):
                 A dictionary of Alluxio property key and values.
                 Note that Alluxio Python API only support a limited set of Alluxio properties.
             concurrency (int, optional):
                 The maximum number of concurrent operations for HTTP requests. Default to 64.
-            etcd_port (int, optional):
-                The port of each etcd server.
+
             worker_http_port (int, optional):
                 The port of the HTTP server on each Alluxio worker node.
-            etcd_refresh_workers_interval(int, optional):
-                The interval to refresh worker list from ETCD membership service periodically. All negative values mean the service is disabled.
-
         """
 
         self.config = AlluxioClientConfig(**kwargs)
         self.session = self._create_session(self.config.concurrency)
-        self.hash_provider = ConsistentHashProvider(self.config)
         self.data_manager = None
         self.logger = logger
-
+        if self.config.load_balance_domain:
+            self.loadbalancer = None
+        elif self.config.worker_hosts:
+            self.loadbalancer = WorkerListLoadBalancer(self.config)
+        else:
+            raise ValueError(
+                "Either 'worker_hosts' or 'load_balance_domain' must be provided."
+            )
         test_options = kwargs.get("test_options", {})
         set_log_level(self.logger, test_options)
         self.executor = None
@@ -338,6 +338,11 @@ class AlluxioClient:
                 data.get("mInAlluxioPercentage", 0),
                 data.get("mContentHash", ""),
             )
+        except requests.exceptions.HTTPError as e:
+            if e.response is not None and e.response.status_code == 500:
+                raise FileNotFoundError(f"File not found: {path}")
+            else:
+                raise
         except Exception:
             raise Exception(
                 EXCEPTION_CONTENT.format(
@@ -1771,29 +1776,35 @@ class AlluxioClient:
                 continue
 
     def _get_preferred_worker_address(self, full_ufs_path):
-        workers = self.hash_provider.get_multiple_workers(full_ufs_path, 1)
-        if len(workers) != 1:
-            raise ValueError(
-                "Expected exactly one worker from hash ring, but found {} workers {}.".format(
-                    len(workers), workers
+        if self.loadbalancer is not None:
+            workers = self.loadbalancer.get_multiple_worker(full_ufs_path, 1)
+            if len(workers) != 1:
+                raise ValueError(
+                    "Expected exactly one worker from hash ring, but found {} workers {}.".format(
+                        len(workers), workers
+                    )
                 )
+            url = GET_NODE_ADDRESS_IP.format(
+                worker_host=workers[0].host,
+                http_port=workers[0].http_server_port,
+                file_path=full_ufs_path,
             )
-        url = GET_NODE_ADDRESS.format(
-            worker_host=workers[0].host,
-            http_port=workers[0].http_server_port,
-            file_path=full_ufs_path,
-        )
-        response = requests.get(url)
-        response.raise_for_status()
-        data = json.loads(response.content)[0]
-        return (
-            data["mBlockInfo"]["mBlockInfo"]["mLocations"][0][
-                "mWorkerAddress"
-            ]["Host"],
-            data["mBlockInfo"]["mBlockInfo"]["mLocations"][0][
-                "mWorkerAddress"
-            ]["HttpServerPort"],
-        )
+        else:
+            url = GET_NODE_ADDRESS_DOMAIN.format(
+                domain=self.config.load_balance_domain,
+                http_port=self.config.worker_http_port,
+                file_path=full_ufs_path,
+            )
+        try:
+            response = self.session.get(url)
+            response.raise_for_status()
+            data = json.loads(response.content)
+            ip = data["Host"]
+            port = data["HttpServerPort"]
+        except HTTPError:
+            ip = workers[0].host
+            port = workers[0].http_server_port
+        return ip, port
 
     def _validate_path(self, path):
         if not isinstance(path, str):
