@@ -120,17 +120,11 @@ class AlluxioFileSystem(AbstractFileSystem):
         to leveraging the data caching and management features of Alluxio.
 
         The Alluxio args:
-            etcd_hosts (str, optional): A comma-separated list of ETCD server hosts in the format "host1:port1,host2:port2,...".
-                ETCD is used for dynamic discovery of Alluxio workers.
-                Either `etcd_hosts` or `worker_hosts` must be specified, not both.
             worker_hosts (str, optional): A comma-separated list of Alluxio worker hosts in the format "host1:port1,host2:port2,...".
-                Directly specifies workers without using ETCD.
-                Either `etcd_hosts` or `worker_hosts` must be specified, not both.
+                Directly specifies workers without using service discovery.
             options (dict, optional): A dictionary of Alluxio configuration options where keys are property names and values are property values.
                 These options configure the Alluxio client behavior.
             concurrency (int, optional): The maximum number of concurrent operations (e.g., reads, writes) that the file system interface will allow. Defaults to 64.
-            etcd_port (int, optional): The port number used by each etcd server.
-                Relevant only if `etcd_hosts` is specified.
             worker_http_port (int, optional): The port number used by the HTTP server on each Alluxio worker.
                 This is used for accessing Alluxio's HTTP-based APIs.
             preload_path (str, optional): Specifies a path to preload into the Alluxio file system cache at initialization.
@@ -361,7 +355,7 @@ class AlluxioFileSystem(AbstractFileSystem):
             path = self.unstrip_protocol(path)
             self.alluxio.get_file_status(path)
             return True
-        except Exception:
+        except FileNotFoundError:
             return False
 
     @fallback_handler
@@ -520,7 +514,7 @@ class AlluxioFileSystem(AbstractFileSystem):
 
     @fallback_handler
     def put_file(self, lpath, rpath, *args, **kwargs):
-        raise NotImplementedError
+        return self.upload(lpath, rpath, *args, **kwargs)
 
     @fallback_handler
     def put(self, lpath, rpath, *args, **kwargs):
@@ -528,43 +522,25 @@ class AlluxioFileSystem(AbstractFileSystem):
 
     @fallback_handler
     def write(self, path, value, **kwargs):
-        return self.upload_data(path, value, **kwargs)
+        path = self.unstrip_protocol(path)
+        return self.alluxio.write_chunked(path, value)
 
     @fallback_handler
     def read(self, path, *args, **kwargs):
-        return self.cat_file(path)
-
-    @fallback_handler
-    def load_file_from_ufs_to_alluxio(self, path, **kwargs):
         path = self.unstrip_protocol(path)
-        return self.alluxio.load(path, **kwargs)
+        return self.alluxio.read_chunked(path)
 
     @fallback_handler
     def upload(self, lpath: str, rpath: str, *args, **kwargs) -> bool:
-        lpath = self.unstrip_protocol(lpath)
-        with open(rpath, "rb") as f:
-            return self.alluxio.write_chunked(lpath, f.read())
-
-    @fallback_handler
-    def upload_data(self, path: str, data: b"", *args, **kwargs) -> bool:
-        path = self.unstrip_protocol(path)
-        return self.alluxio.write_chunked(path, data)
+        rpath = self.unstrip_protocol(rpath)
+        with open(lpath, "rb") as f:
+            return self.alluxio.write_chunked(rpath, f.read())
 
     @fallback_handler
     def download(self, lpath, rpath, *args, **kwargs):
-        lpath = self.unstrip_protocol(lpath)
-        with open(rpath, "wb") as f:
-            return f.write(self.alluxio.read_chunked(lpath).read())
-
-    @fallback_handler
-    def download_data(self, lpath, *args, **kwargs):
-        lpath = self.unstrip_protocol(lpath)
-        return self.alluxio.read_chunked(lpath)
-
-    @fallback_handler
-    def download_batch_data(self, lpath, *args, **kwargs):
-        lpath = self.unstrip_protocol(lpath)
-        return self.alluxio.read_batch(lpath)
+        rpath = self.unstrip_protocol(rpath)
+        with open(lpath, "wb") as f:
+            return f.write(self.alluxio.read_chunked(rpath).read())
 
     @fallback_handler
     def get(self, rpath, lpath, *args, **kwargs):
@@ -574,6 +550,7 @@ class AlluxioFileSystem(AbstractFileSystem):
     def get_file(self, rpath, lpath, *args, **kwargs):
         raise NotImplementedError
 
+    @fallback_handler
     def read_block(self, *args, **kwargs):
         if self.fs:
             return self.fs.read_block(*args, **kwargs)
